fn resolve_line_height_length(
context: &Context<'_>,
length: NoCalcLength,
) -> CSSPixelLengthExpand description
Resolves a line-height length into an absolute pixel value, properly applying text
scaling and ensuring any lh lengths are resolved against the inherited line-height.